@@ -153,7 +153,7 @@ class SvnClient(VcsClientBase):
                 command += sanitized('-r%s'%spec)
         command += " %s"%self._path
         # #3305: parsing not robust to non-US locales
-        _, output, _ = run_shell_command(command, shell=True, us_env = True, show_stdout = True)
+        _, output, _ = run_shell_command(command, shell=True, us_env = True)
         if output != None:
             matches = [l for l in output.splitlines() if l.startswith('Revision: ')]
             if len(matches) == 1:
