@@ -82,13 +82,22 @@ def sanitized(arg):
 
 def discard_line(line):
     # the most common feedback lines of scms. We don't care about those. We let through anything unusual only.
-    discard_prefixes = ["adding ", "added ", "updating ", "requesting ", "pulling from ", "searching for ", "(", "no changes found", "0 files", "A  ", "D  ", "U  ", "At revision", "Path: "]
+    discard_prefixes = ["adding ", "added ", "updating ", "requesting ", "pulling from ",
+                        "searching for ", "(", "no changes found",
+                        "0 files",
+                        "A  ", "D  ", "U  ", 
+                        "At revision", "Path: ", "First,",
+                        "Installing", "Using ",
+                        "No ", "Tree ",
+                        "All ", 
+                        "+N  ", "-D  ", " M  ", " M* ", "RM" # bzr
+                        ]
     for d in discard_prefixes:
         if line.startswith(d):
             return True
     return False
 
-def run_shell_command(cmd, cwd=None, shell=False, us_env = True, show_stdout = False):
+def run_shell_command(cmd, cwd=None, shell=False, us_env = True, show_stdout = False, verbose = False):
     """
     executes a command and hides the stdout output, loggs
     stderr output when command result is not zero. Make sure to sanitize arguments in the command.
@@ -108,29 +117,38 @@ def run_shell_command(cmd, cwd=None, shell=False, us_env = True, show_stdout = F
                              stderr=subprocess.PIPE,
                              stdout=subprocess.PIPE,
                              env=env)
-        if show_stdout:
+        # when we read output in while loop, it will not be returned in communicate()
+        stderr_buf = []
+        stdout_buf = []
+        if verbose or show_stdout:
             # listen to stdout and print
             while True:
                 line = p.stdout.readline()
                 if line != '':
-                    if not discard_line(line):
+                    if verbose or not discard_line(line):
                         print(line),
-                line = p.stderr.readline()
-                if line != '':
-                    if not discard_line(line):
-                        print(line),
-                if(not line or p.returncode is not None):
-                        break
-        output = p.communicate()
+                        stdout_buf.append(line)
+                line2 = p.stderr.readline()
+                if line2 != '':
+                    if verbose or not discard_line(line2):
+                        print(line2),
+                        stderr_buf.append(line2)
+                if ((not line and not line2) or p.returncode is not None):
+                    break
+        (stdout, stderr) = p.communicate()
+        stdout_buf.append(stdout)
+        stdout = "\n".join(stdout_buf)
+        stderr_buf.append(stderr)
+        stderr = "\n".join(stderr_buf)
         message = None
-        if p.returncode != 0 and output[1] is not None and output[1] != '':
+        if p.returncode != 0 and stderr is not None and stderr != '':
             logger = logging.getLogger('vcstools')
             message = "Command failed: '%s'"%(cmd)
             if cwd is not None:
                 message += "\n run at: '%s'"%(cwd)
-            message += "\n errcode: %s:\n%s"%(p.returncode, output[1])
+            message += "\n errcode: %s:\n%s"%(p.returncode, stderr)
             logger.warn(message)
-        result = output[0]
+        result = stdout
         if result is not None:
             result = result.rstrip()
         return (p.returncode, result, message)
@@ -193,7 +211,7 @@ class VcsClientBase:
         """
         raise NotImplementedError, "Base class get_version method must be overridden"
 
-    def checkout(self, url, version):
+    def checkout(self, url, version, verbose = False):
         """
         Attempts to create a local repository given a remote
         url. Fails if a direcotry exists already in target
@@ -208,7 +226,7 @@ class VcsClientBase:
         """
         raise NotImplementedError("Base class checkout method must be overridden")
 
-    def update(self, spec):
+    def update(self, spec, verbose = False):
         """
         Sets the local copy of the repository to a version matching
         the spec. Fails when there are uncommited changes.
